//---------------------------------------------------------------------------
//
// Evj        Model the evolution of DNA binding site recognition
//
// Module:    PopupHTMLbrowser, display Evj help in a browser.
// Author:    Paul C. Anagnostopoulos
// Created:   28 October 2005
//
// Origin:    This is a modification of a class written by Peter Lemkin.
//
// This computer program fits the description in the U.S. Copyright Act
// of a "United States Government work." It was written as a part of
// my/our official duties as a Government employee. This means it cannot
// be copyrighted. The program is freely available for use without a
// copyright notice, and there are no restrictions on its use, now or
// subsequently. We retain no rights in the program. Please acknowledge
// the source of this code in any releases you make.
//
//---------------------------------------------------------------------------

/* File: PopupHTMLbrowser.java */

///package O2Plib.gui;

import java.awt.*;
import java.io.*;

///import O2Plib.misc.*;

/**
 * Class PopupHTMLbrowser is the popup a web browser on 
 * the specified URL string.
 *<P>
 * This code was derived from MAExplorer at
 * http://maexplorer.sourceforge.net/
 *<P>
 * This work was produced by Peter Lemkin of the National Cancer
 * Institute, an agency of the United States Government.  As a work of
 * the United States Government there is no associated copyright.  It is
 * offered as open source software under the Mozilla Public License
 * (version 1.1) subject to the limitations noted in the accompanying
 * LEGAL file. This notice must be included with the code. The Open2Dprot 
 * Mozilla and Legal files are available on 
 * http://open2dprot.sourceforge.net/
 *<P>
 * @author P. Lemkin (LECB/NCI), G. Thornwall (SAIC), Frederick, MD
 * @version $Date: 2005/10/21 15:42:54 $   $Revision: 1.6 $
 * @see <A HREF="http://open2dprot.sourceforge.net/">Open2Dprot Home</A>
 */

public class PopupHTMLbrowser extends Frame
{ /* PopupHTMLbrowser */
  
  /** frame id */
  final static long
	serialVersionUID= 0;
		
  /**
   * PopupHTMLbrowser() - constructor
   * @param urlStr to display in popup browser. It is the file's url
   *            (the url must start with either "http://" or"file://").
   * @param windowName to use for the new popup window

   */
  public PopupHTMLbrowser(String urlStr, String windowName)
  { /* PopupHTMLbrowser*/ 
    popupHTMLbrowser(urlStr, windowName);
  } /* PopupHTMLbrowser*/
  
  
  /**
   * popupHTMLbrowser() - Display URL file in system Web browser.
   * This assumes that you have added the proper plugin to your browser
   * for this data if required.
   *<PRE>
   * Examples:
   * displayURL("http://www.javaworld.com")
   * displayURL("file://c:\\docs\\index.html")
   * displayURL("file:///user/joe/index.html");
   * displayURL("file:///user/joe/image.gif");
   * displayURL("file:///user/joe/image.pdf");
   * displayURL("file:///user/joe/image.xml");
   * displayURL("file:///user/joe/image.svg");
   *</PRE>
   * Under Unix, the system browser is hard-coded to be 'netscape'.
   * Netscape must be in your PATH for this to work.
   *<BR>
   * Under Windows, this will bring up the default browser under windows,
   * usually either Netscape or Microsoft IE. The default browser is
   * determined by the OS.
   *<BR>
   * adapted from :
   * http://www.javaworld.com/javaworld/javatips/jw-javatip66_p.html
   *<BR>
   * @param urlStr to display in popup browser. It is the file's url
   *            (the url must start with either "http://" or"file://").
   * @param windowName to use for the new popup window
   * @return false if error.
   */
  public boolean popupHTMLbrowser(String urlStr, String windowName)
  { /* popupHTMLbrowser */  
    /* name of this operating system: Property("os.name") */
    String osName= System.getProperty("os.name");  
    
    /* [TODO] Handle the Mac better. */
   
    String
      WIN_PATH= "rundll32",	          /* default browser under windows*/
      WIN_FLAG= "url.dll,FileProtocolHandler", /* flag to display url */
      UNIX_PATH= "netscape",	        /* default browser under UNIX */
      UNIX_FLAG= "-remote openURL";   /* flag to display a url.*/
    String cmd= null;
    
    try
    { /* try to start browser */
      if(osName!=null && osName.startsWith("Windows"))
      { /* windows */
        /* cmd= "rundll32 url.dll,FileProtocolHandler http://..." */
        cmd= WIN_PATH + " " + WIN_FLAG + " " + urlStr;
        Process p= Runtime.getRuntime().exec(cmd);
        if(p==null)
          return(false);
      } /* windows */
      
      /* Mac Code  [JE-06-6-2001]
       * Use the MRJ from Apple to envoke the default browser
       */
      else if(osName.startsWith("Mac"))
      { /* Macintosh */
        try
        {
          Class C = Class.forName("com.apple.mrj.MRJFileUtils");
          C.getMethod("openURL",
                      new Class [] {Class.forName("java.lang.String")}
                     ).invoke((Object)null, new Object [] {urlStr});
        }
        catch(ClassNotFoundException e)
        {
///          Util.appendPRmsg(
///        "Can't start Web browser - missing 'com.apple.mrj.MRJFileUtils'\n");
          return(false);
        } /* Macintosh */
        catch(Exception e)
        { /* this catches following exceptions related to envoking MRJ
           * + NoSuchMethodException
           * + SecurityException
           * + IllegalAccessException
           * + IllegalArgumentExceptionb
           * + InvocationTargetException
           */
///           Util.appendPRmsg(
///                "Can't start Mac Web browser, old version of MRJ "+e+"\n");
           return(false);
        }
      }
      
      else
      { /* UNIX */
        /* Under Unix, Netscape has to be running for the
         * "-remote" command to work. So, we try sending the
         * command and check for an exit value. If the exit
         * command is 0, it worked, otherwise we need to start
         * the browser.
         */
        cmd= UNIX_PATH + " " + UNIX_FLAG + "(" + urlStr + ")";
        Process p= Runtime.getRuntime().exec(cmd);
        
        try
        { /* wait for exit code -- if it's 0, command worked,
           * otherwise we need to start the browser up.
           */          
          if(p.waitFor()!=0)
          {
            /* Command failed, start up the browser*/
            cmd= UNIX_PATH + " " + urlStr;
            p= Runtime.getRuntime().exec(cmd);
          }
        }
        catch(InterruptedException x)
        {
          String msg= "Can't start browser";
///          Util.appendPRmsg(msg);
          return(false);
        }
      } /* UNIX */
    } /* try to start browser */
    
    catch(IOException e)               /* couldn't exec browser*/
    {
      String msg= "Can't start browser";
///      Util.appendPRmsg(msg);
      return(false);
    }
    
    return(true);
  } /* popupHTMLbrowser */

  
  
} /* End of class PopupHTMLbrowser */
